@@ -117,7 +117,7 @@ if(plot_species_n == 1){
   pr_plot <- pr_plot +
     ggplot2::coord_sf() +
     ggplot2::ggtitle(paste(map_title))+
-    ggplot2::geom_point(data = object[!object$species %in% "Confidential",], aes_string(x = "longitude", y = "latitude", fill = "pr", size = "examined"), alpha = 0.8, shape = 21, na.rm = TRUE)+
+    ggplot2::geom_point(data = object[!object$species %in% "Confidential",], aes(.data$longitude, .data$latitude, fill = .data$pr, size = .data$examined), alpha = 0.8, shape = 21, na.rm = TRUE)+
     ggplot2::theme(plot.title = ggplot2::element_text(vjust=-1),
                    strip.text = ggplot2::element_text(face = "bold"),
                    strip.background = element_blank(),
@@ -134,7 +134,7 @@ if(plot_species_n == 1){
   pr_plot <- pr_plot +
     ggplot2::coord_sf() +
     ggplot2::ggtitle(paste(map_title))+
-    ggplot2::geom_point(data = object[!object$species %in% "Confidential",], aes_string(x = "longitude", y = "latitude", fill = "pr", size = "examined"), alpha = 0.8, shape = 21, na.rm = TRUE)+
+    ggplot2::geom_point(data = object[!object$species %in% "Confidential",], aes(.data$longitude, .data$latitude, fill = .data$pr, size = .data$examined), alpha = 0.8, shape = 21, na.rm = TRUE)+
     ggplot2::theme(plot.title = ggplot2::element_text(vjust=-1),
                    strip.text = ggplot2::element_text(face = "bold"),
                    strip.background = element_blank(),
@@ -155,7 +155,7 @@ if(plot_species_n == 1){
 
   if("Confidential" %in% unique(object$species)){
     pr_plot$layers <- c(pr_plot$layers[[1]], geom_point(data = object[object$species == "Confidential",],
-                 aes_string(x = 'longitude', y = 'latitude'),
+                 aes(.data$longitude, .data$latitude),
                  fill = "grey40", colour = "grey40", size = 1, shape = 21, alpha = 0.8), pr_plot$layers[[2]])
     pr_plot <- pr_plot +
       ggtitle(label = paste(map_title), subtitle = "(confidential data shown in grey)")
